<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:lxslt="http://xml.apache.org/xslt" xmlns:redirect="com.scenari.xsldom.xalan.lib.Redirect" xmlns:java="http://xml.apache.org/xslt/java" extension-element-prefixes="redirect java lxslt ">
<xsl:output method="xml" indent="no"/>
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>
<xsl:template match="bibContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'bib'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'bib_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'bib'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'bib_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'bib'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>


<xsl:overlay match="body">
<xsl:if test="//scBasket and //scTooltip[@render = 'asTooltip']">
<xsl:value-of select="execute(java:append($vBufJs, 'scTooltipMgr.registerTooltips();'))"/>
</xsl:if>
</xsl:overlay>

<xsl:template match="scTooltip">
<xsl:variable name="vKey" select="string(@basketKey)"/>
<xsl:choose>
<xsl:when test="@basketKey and boolean(//scBasket[@key=$vKey])">
<xsl:variable name="vItemKey" select="string(@itemKey)"/>
<xsl:variable name="vIdAnc" select="string(@id)"/>
<xsl:variable name="vIdInBskt" select="concat($vKey, generate-id(java:get($vBasketPool, $vKey)[@itemKey = $vItemKey][1]))"/>
<xsl:variable name="vEltRank"><xsl:for-each select="java:get($vBasketPool, $vKey)"><xsl:value-of select="if(@itemKey = $vItemKey, position(), '')"/></xsl:for-each></xsl:variable>
<xsl:variable name="vRefAnc" select="if(//scBasket[@key=$vKey][1]/@tagName = 'ol',$vEltRank,'*')"/>
<xsl:for-each select="child::*[not(starts-with(local-name(),'scTooltip'))]">
<xsl:variable name="vTagName">
<xsl:choose>
<xsl:when test="boolean(descendant::a | ancestor::a)">span</xsl:when>
<xsl:otherwise><xsl:value-of select="local-name()"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="vTrigger">
<xsl:choose>
<xsl:when test="boolean(descendant::a | ancestor::a) and ../@trigger='onclick'">onmouseover</xsl:when>
<xsl:otherwise><xsl:value-of select="../@trigger"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:element name="{$vTagName}">
<xsl:for-each select="@*">
<xsl:apply-templates select="."/>
</xsl:for-each>
<xsl:attribute name="id"><xsl:value-of select="$vIdAnc"/></xsl:attribute>
<xsl:if test="$vTagName = 'a' and @href = '#'"><xsl:attribute name="href">#<xsl:value-of select="$vIdInBskt"/></xsl:attribute></xsl:if>
<xsl:if test="../@render = 'asTooltip'">
<xsl:attribute name="data-sctooltip">{"ttId":"<xsl:value-of select="$vIdInBskt"/>","trigger":"<xsl:value-of select="$vTrigger"/>","class":"<xsl:value-of select="../@class"/>","classRoot":"<xsl:value-of select="../@classRoot"/>","options":{<xsl:value-of select="if(../@basketLnk='no','&quot;NOREF&quot;:true,')"/><xsl:value-of select="../@options"/>}}</xsl:attribute>
</xsl:if>
<xsl:apply-overlays/>
<xsl:apply-templates/>
</xsl:element>
</xsl:for-each>
<xsl:if test="not(@basketLnk='no')">
<xsl:apply-templates select="." mode="refAnc">
<xsl:with-param name="pIdInBskt" select="$vIdInBskt" />
<xsl:with-param name="pRefAnc" select="$vRefAnc" />
</xsl:apply-templates>
</xsl:if>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="vTTTitle">
<xsl:choose>
<xsl:when test="$vOutputTypeXml">
<redirect:serialize omit-xml-declaration="yes" method="xml"><xsl:apply-templates select="scTooltipTitle/node()"/></redirect:serialize>
</xsl:when>
<xsl:otherwise>
<redirect:serialize omit-xml-declaration="yes" method="html"><xsl:apply-templates select="scTooltipTitle/node()"/></redirect:serialize>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="vTTContent">
<xsl:choose>
<xsl:when test="$vOutputTypeXml">
<redirect:serialize omit-xml-declaration="yes" method="xml"><xsl:apply-templates select="scTooltipContent/node()"/></redirect:serialize>
</xsl:when>
<xsl:otherwise>
<redirect:serialize omit-xml-declaration="yes" method="html"><xsl:apply-templates select="scTooltipContent/node()"/></redirect:serialize>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="vTTTrigger" select="@trigger"/>
<xsl:variable name="vTTAttr">return scTooltipMgr.showTooltip(this,event,&quot;<xsl:value-of select="escapeJs(normalize-space($vTTContent))"/>&quot;,&quot;<xsl:value-of select="escapeJs(normalize-space($vTTTitle))"/>&quot;,&quot;<xsl:value-of select="@class"/>&quot;,&quot;<xsl:value-of select="@classRoot"/>&quot;,{<xsl:value-of select="@options"/>});</xsl:variable>
<xsl:for-each select="child::*[not(starts-with(local-name(),'scTooltip'))]">
<xsl:variable name="vTagName">
<xsl:choose>
<xsl:when test="boolean(descendant::a | ancestor::a)">span</xsl:when>
<xsl:otherwise><xsl:value-of select="local-name()"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:element name="{$vTagName}">
<xsl:attribute name="{if((boolean(descendant::a | ancestor::a)) and $vTTTrigger='onclick','onmouseover',$vTTTrigger)}"><xsl:value-of select="$vTTAttr"/></xsl:attribute>
<xsl:apply-templates select="@*"/>
<xsl:apply-overlays/>
<xsl:apply-templates/>
</xsl:element>
</xsl:for-each>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template match="scTooltip" mode="refAnc">
<xsl:param name="pIdInBskt" />
<xsl:param name="pRefAnc" />
<sup class="{addSuffixOnWords(@class, '_ref')}">
<a href="#{$pIdInBskt}"><span>[</span><xsl:value-of select="$pRefAnc"/><span>]</span></a>
</sup>
</xsl:template>
<xsl:template match="a//scTooltip" mode="refAnc">
<xsl:param name="pRefAnc" />
<sup class="{addSuffixOnWords(@class, '_ref')}">
<span>[</span><xsl:value-of select="$pRefAnc"/><span>]</span>
</sup>
</xsl:template>
	

<xsl:variable name="vBufJs" select="java:java.lang.StringBuffer.new()"/>
<xsl:overlay match="body" mode="endBodyTags" priority="100"><xsl:if test="java:length($vBufJs) &gt; 0"><script type="text/javascript"><xsl:value-of select="java:toString($vBufJs)"/></script></xsl:if></xsl:overlay>
	
<xsl:template match="questContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'quest'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'quest_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'quest'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'quest_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'quest'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>

<xsl:template match="keywdLinks">
	<xsl:variable name="vItemKey" select="string(../../@itemKey)"/>
	<div class="keywdLinks">
		<xsl:for-each select="//scTooltip[@itemKey=$vItemKey]">
			<a href="#{@id}"><span>^</span></a>
		</xsl:for-each>
	</div>
</xsl:template>

<xsl:variable name="vOutputTypeXml" select="true()"/>
	
<xsl:template match="creditsContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'cprRes'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'credit_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'cprRes'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'credit_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'cprRes'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>

<xsl:template match="ucContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'ucLnk'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'ucLnk_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'ucLnk'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'ucLnk_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'ucLnk'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>

<xsl:template match="ul[preceding-sibling::a[contains(@class,'assmntUa_ti_lo')]]"/>
<xsl:template match="ul[preceding-sibling::a[contains(@class,'quiz_ti_lo')]]"/>
<xsl:template match="span[contains(@class,'coLnk_ul')]/span | span[contains(@class,'sectionTitle')]">
  <xsl:variable name="vTargetId" select="idNode/@id"/>
  <xsl:variable name="vTarget" select="//*[idNode/@id=$vTargetId and not(parent::span[contains(@class,'coLnk_ul')]) and not(parent::span[contains(@class,'sectionTitle')])][1]"/>
  <xsl:choose>
    <xsl:when test="$vTarget/@id">
      <a href="#{$vTarget/@id}">
        <xsl:apply-templates select="@*"/>
        <xsl:apply-overlays/>
        <xsl:apply-templates/></a>
    </xsl:when>
    <xsl:otherwise>
      <xsl:copy>
        <xsl:apply-templates select="@*"/>
        <xsl:apply-overlays/>
        <xsl:apply-templates/>
      </xsl:copy>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="cprResLinks">
	<xsl:variable name="vItemKey" select="string(../../@itemKey)"/>
	<span class="cprResLinks">
		<xsl:for-each select="//scTooltip[@itemKey=$vItemKey]">
			<a href="#{following-sibling::figure/@id}"><span>^</span></a>
		</xsl:for-each>
	</span>
</xsl:template>
<xsl:template match="glossContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'glos'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'glos_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'glos'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'glos_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'glos'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>

<xsl:key name="ttByItemKey" match="scTooltip" use="@itemKey" />

<xsl:template match="cprResBackRefs">
	<xsl:variable name="vItemKey" select="string(../../@itemKey)" />
	<span class="backRefs backRefs_cprRes">
		<xsl:for-each select="key('ttByItemKey', $vItemKey)">
			<!-- Test si le tooltip est inclu dans un tooltip parent non pas publié (cad qui n'est pas le premier dans le document) -->
			<xsl:variable name="vParentTooltip" select="(ancestor::scTooltip)[1]" />
			<xsl:if test="not(count($vParentTooltip)) or generate-id($vParentTooltip) = generate-id(key('ttByItemKey', $vParentTooltip/@itemKey))">
				<xsl:variable name="vParent" select="parent::*" />
				<a href="#{if($vParent/@id, $vParent/@id, generate-id($vParent))}" />
			</xsl:if>
		</xsl:for-each>
	</span>
</xsl:template>

<xsl:template match="addTableIndex">
	<xsl:attribute name="class">
		<xsl:value-of select="concat(../@class,' indexType_',@type)"/>
	</xsl:attribute>
</xsl:template>

<xsl:template match="solutionsContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'solution'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'solution_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'solution'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'solution_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'solution'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>

<xsl:template match="quizLinks">
	<xsl:variable name="vItemKey" select="string(../../@itemKey)"/>
	<span class="quizLinks">
		<xsl:for-each select="//scTooltip[@itemKey=$vItemKey]">
			<a href="#{ancestor::*[contains(@class, 'exercice')]/*[contains(@class, 'exercice_ti')]/@id}"><span>^</span></a>
		</xsl:for-each>
	</span>
</xsl:template>

<xsl:template match="refContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'ref'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'ref_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'ref'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'ref_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'ref'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>


<xsl:template match="alternative"><xsl:apply-templates/></xsl:template>
<xsl:template match="@lookForAlt"><xsl:attribute name="alt"><xsl:value-of select="if(.='', ancestor::alternative/@alt, .)"/></xsl:attribute></xsl:template>	
	

<xsl:overlay match="/">
<xsl:for-each select="//scBasket">
<xsl:variable name="vKey" select="string(@key)"/>
<xsl:variable name="vUnicity" select="java:java.util.HashSet.new()"/>
<xsl:value-of select="execute(java:put($vBasketPool, $vKey, lxslt:nodeset(//scTooltip[@basketKey=$vKey][java:add($vUnicity, string(@itemKey))])))"/> 
</xsl:for-each>	
</xsl:overlay>
<xsl:template match="scBasket">
<xsl:variable name="vClass" select="@widgetClass"/>
<xsl:variable name="vKey" select="string(@key)"/>
<xsl:variable name="vHasElts" select="boolean(java:get($vBasketPool, $vKey))"/>
<xsl:if test="$vHasElts or @suppressIfEmpty = 'no'">
<xsl:choose>
<xsl:when test="scBlock">
<xsl:element name="{returnFirst(scBlock/@tagName, 'div')}">
<xsl:attribute name="class"><xsl:value-of select="concat(@class,' ',$vClass)"/></xsl:attribute>
<xsl:variable name="vCount" select="count(ancestor::scBlock)+1"/>
<xsl:variable name="vMaxHx"><xsl:call-template name="maxHeadingNumber"/></xsl:variable>
<xsl:element name="{concat('h', if($vCount &gt; $vMaxHx, $vMaxHx, $vCount))}">
<xsl:apply-templates select="scBlock/hx/@*"/>
<xsl:apply-overlays select="scBlock/hx/node()"/>
<xsl:apply-templates select="scBlock/hx/node()"/>
</xsl:element>
<xsl:apply-templates select="." mode="scBasketList"/>
</xsl:element>
</xsl:when>
<xsl:when test="scBasketTitle">
<div>
<xsl:attribute name="class"><xsl:value-of select="concat(@class,' ',$vClass)"/></xsl:attribute>
<div>
<xsl:attribute name="class"><xsl:value-of select="addSuffixOnWords($vClass, '_ti')"/></xsl:attribute>
<xsl:apply-templates select="scBasketTitle/node()"/>
</div>
<xsl:apply-templates select="." mode="scBasketList"/>
</div>
</xsl:when>
<xsl:otherwise>
<xsl:apply-templates select="." mode="scBasketList"/>
</xsl:otherwise>
</xsl:choose>
</xsl:if>
</xsl:template>
<xsl:template match="scBasket" mode="scBasketList">
<xsl:variable name="vClass" select="@widgetClass"/>
<xsl:variable name="vKey" select="string(@key)"/>
<xsl:variable name="vChiTagName" select="if(@tagName='div','div','li')"/>
<xsl:element name="{@tagName}">
<xsl:choose>
<xsl:when test="scBlock|scBasketTitle">
<xsl:attribute name="class"><xsl:value-of select="addSuffixOnWords($vClass, '_li')"/></xsl:attribute>
<xsl:attribute name="data-titled-basket">true</xsl:attribute>
</xsl:when>
<xsl:otherwise>
<xsl:attribute name="class"><xsl:value-of select="concat(@class,' ',$vClass)"/></xsl:attribute>
</xsl:otherwise>
</xsl:choose>
<xsl:choose>
<xsl:when test="@sort='byTitle'">
<xsl:for-each select="java:get($vBasketPool, $vKey)">
<xsl:sort select="scTooltipTitle" data-type="text"/>
<xsl:apply-templates select="." mode="scBasketItem">
<xsl:with-param name="vClass" select="$vClass"/>
<xsl:with-param name="vChiTagName" select="$vChiTagName"/>
</xsl:apply-templates>
</xsl:for-each>
</xsl:when>
<xsl:when test="@sort='byContent'">
<xsl:for-each select="java:get($vBasketPool, $vKey)">
<xsl:sort select="scTooltipContent" data-type="text"/>
<xsl:apply-templates select="." mode="scBasketItem">
<xsl:with-param name="vClass" select="$vClass"/>
<xsl:with-param name="vChiTagName" select="$vChiTagName"/>
</xsl:apply-templates>
</xsl:for-each>
</xsl:when>
<xsl:when test="@sort='byTitleDesc'">
<xsl:for-each select="java:get($vBasketPool, $vKey)">
<xsl:sort select="scTooltipTitle" data-type="text" order="descending"/>
<xsl:apply-templates select="." mode="scBasketItem">
<xsl:with-param name="vClass" select="$vClass"/>
<xsl:with-param name="vChiTagName" select="$vChiTagName"/>
</xsl:apply-templates>
</xsl:for-each>
</xsl:when>
<xsl:when test="@sort='byContentDesc'">
<xsl:for-each select="java:get($vBasketPool, $vKey)">
<xsl:sort select="scTooltipContent" data-type="text" order="descending"/>
<xsl:apply-templates select="." mode="scBasketItem">
<xsl:with-param name="vClass" select="$vClass"/>
<xsl:with-param name="vChiTagName" select="$vChiTagName"/>
</xsl:apply-templates>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="java:get($vBasketPool, $vKey)">
<xsl:apply-templates select="." mode="scBasketItem">
<xsl:with-param name="vClass" select="$vClass"/>
<xsl:with-param name="vChiTagName" select="$vChiTagName"/>
</xsl:apply-templates>
</xsl:for-each>
</xsl:otherwise>
</xsl:choose>
</xsl:element>
</xsl:template>
<xsl:template match="*" mode="scBasketItem">
<xsl:param name="vClass"/>
<xsl:param name="vChiTagName"/>
<xsl:choose>
<xsl:when test="local-name() = 'scTooltip'">
<xsl:variable name="vIdInBskt" select="concat(@basketKey, generate-id(.))"/>
<xsl:element name="{$vChiTagName}">
<xsl:attribute name="class"><xsl:value-of select="addSuffixOnWords($vClass, '_it')"/></xsl:attribute>
<xsl:attribute name="id"><xsl:value-of select="$vIdInBskt"/></xsl:attribute>
<div class="{addSuffixOnWords($vClass, '_itti')}">
<xsl:choose>
<xsl:when test="scTooltipTitle"><xsl:apply-templates select="scTooltipTitle/node()"/></xsl:when>
<xsl:otherwise><xsl:attribute name="style">display:none;</xsl:attribute></xsl:otherwise>
</xsl:choose>
</div>
<div class="{addSuffixOnWords($vClass, '_itco')}">
<xsl:choose>
<xsl:when test="scTooltipContent"><xsl:apply-templates select="scTooltipContent/node()"/></xsl:when>
<xsl:otherwise><xsl:attribute name="style">display:none;</xsl:attribute></xsl:otherwise>
</xsl:choose>
</div>
</xsl:element>		
</xsl:when>
</xsl:choose>
</xsl:template>
	
<xsl:template match="div[contains(@class,'genRefBk')]"/>

<xsl:template match="scBlock[@tagName='none']"><xsl:apply-overlays/><xsl:apply-templates/></xsl:template>
<xsl:template match="scBlock"><xsl:element name="{returnFirst(@tagName, 'div')}"><xsl:apply-templates select="@*"/><xsl:apply-overlays/><xsl:apply-templates/></xsl:element></xsl:template>
<xsl:template match="scBlockTitle"/>
	

<xsl:variable name="vBasketPool" select="java:java.util.HashMap.new()"/>
	
<xsl:overlay match="a[contains(@class,'op_txt_ul') and not(contains(string(.), returnFirst(substring-after(@href, '://'), @href)))]">
	<xsl:attribute name="class"><xsl:value-of select="@class"/> showHref</xsl:attribute>
</xsl:overlay>

<xsl:overlay match="html"><xsl:attribute name="xmlns">http://www.w3.org/1999/xhtml</xsl:attribute></xsl:overlay>
	
<xsl:overlay match="body">
	<xsl:if test="//addClassToBody">
		<xsl:attribute name="class"><xsl:value-of select="concat(@class, ' ', concatExpr(//addClassToBody, text(), ' '))"/></xsl:attribute>
	</xsl:if>
</xsl:overlay>
<xsl:template match="addClassToBody"/>
<xsl:template match="indexContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'keywd'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'index_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'keywd'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'index_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'keywd'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>

<xsl:template match="resContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'resLnk'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'resLnk_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'resLnk'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'resLnk_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'resLnk'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>

<xsl:overlay match="head" mode="endHeadTags">
	<xsl:apply-templates select="//scBlock[@id='toc']" mode="bookmarks"/>
</xsl:overlay>
<xsl:template match="scBlock[@id='toc']" mode="bookmarks">
	<bookmarks>
		<xsl:apply-templates mode="bookmarks"/>
	</bookmarks>
</xsl:template>
<xsl:template match="* | text()" mode="bookmarks">
	<xsl:apply-templates mode="bookmarks"/>
</xsl:template>
<xsl:template match="li" mode="bookmarks">
	<xsl:call-template name="bookmark"/>
</xsl:template>
<xsl:template name="bookmark">
	<xsl:if test="boolean(a)">
		<bookmark name="{normalize-space(a/ifTextIgnore/span[contains(@class, 'title')])}" href="{a/@href}_a">
			<xsl:apply-templates mode="bookmarks"/>
		</bookmark>
	</xsl:if>
</xsl:template>

<!-- Add level on h6  -->
<xsl:template match="hx" priority="1">
	<xsl:variable name="vCount" select="count(ancestor::scBlock)"/>

	<xsl:choose>
		 <xsl:when test="$vCount >6">
			<div class="hx_level_{$vCount}">
				<xsl:element name="{concat('h', if($vCount &gt; 6, '6', $vCount))}">
					<xsl:apply-templates select="@*"/>
					<xsl:apply-overlays/>
					<a name="{@id}_a"/>
					<xsl:apply-templates/>
				</xsl:element>
			</div>
		 </xsl:when>
		 <xsl:otherwise>
				<xsl:element name="{concat('h', if($vCount &gt; 6, '6', $vCount))}">
					<xsl:apply-templates select="@*"/>
					<xsl:apply-overlays/>
					<a name="{@id}_a"/>
					<xsl:apply-templates/>
				</xsl:element>
		 </xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="acrContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'acr'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'acr_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'acr'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'acr_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'acr'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>


<xsl:template match="crossRef"/>
<xsl:overlay match="*[crossRef]" priority="1">
<xsl:variable name="vId" select="java:ensureIdOnCurrentResultElt($vDialog, string(crossRef[@prefId]/@prefId))"/>
<xsl:for-each select="crossRef/entry"><xsl:value-of select="java:com.scenari.m.ge.generator.web.CrossRefEntry.addEntry($vDialog, $vId, @keyRef, @value)"/></xsl:for-each>
</xsl:overlay>
	
<xsl:template match="webContainer">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'web'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:apply-templates select="@*|node()"/>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'web_ti_lo')]">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'web'))>0"/>
	<xsl:if test="$vHasElts">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-overlays/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:if>
</xsl:template>
<xsl:template match="li[contains(a/@class,'web_ti_lo')]" mode="bookmarks">
	<xsl:variable name="vHasElts" select="count(java:get($vBasketPool, 'web'))>0"/>
  <xsl:if test="$vHasElts">
	<xsl:call-template name="bookmark"/>
  </xsl:if>
</xsl:template>


<xsl:template match="/"><xsl:apply-overlays/><xsl:apply-templates select="node()"/></xsl:template>
<xsl:template match="head">
<xsl:copy>
<xsl:apply-templates select="@*"/>
<xsl:apply-overlays select="." mode="startHeadTags"/>
<xsl:apply-overlays/>
<xsl:apply-templates/>
<xsl:apply-overlays select="." mode="endHeadTags"/>
</xsl:copy>
</xsl:template>
<xsl:template match="body">
<xsl:copy>
<xsl:apply-templates select="@*"/>
<xsl:apply-overlays select="." mode="startBodyTags"/>
<xsl:apply-overlays select="." mode="startTags"/>
<xsl:apply-overlays/>
<xsl:apply-templates/>
<xsl:apply-overlays select="." mode="endTags"/>
<xsl:apply-overlays select="." mode="endBodyTags"/>
</xsl:copy>
</xsl:template>
<xsl:template match="zoneContent"><xsl:apply-overlays/><xsl:apply-templates/></xsl:template>
<xsl:template match="ifText">
<xsl:variable name="vRoot" select="if(@root='firstChild', */*[1], if(@root='lastChild', */*[last()], .))"/>
<xsl:if test="$vRoot/descendant::text()[string-length(normalize-space())&gt;0 and not(./ancestor::ifTextIgnore)] | $vRoot/descendant::img[not(./ancestor::ifTextIgnore)] | $vRoot/descendant::audio[not(./ancestor::ifTextIgnore)] | $vRoot/descendant::video[not(./ancestor::ifTextIgnore)] | $vRoot/descendant::object[not(./ancestor::ifTextIgnore)] | $vRoot/descendant::input[not(./ancestor::ifTextIgnore)] | $vRoot/descendant::iframe[not(./ancestor::ifTextIgnore)]"><xsl:apply-templates/></xsl:if>
</xsl:template>
<xsl:template match="ifTextIgnore">
<xsl:apply-templates/>
</xsl:template>
<xsl:template name="maxHeadingNumber"><xsl:value-of select="genProp('max.heading.number-int', 6)"/></xsl:template>
<xsl:template match="hx">
<xsl:variable name="vCount" select="count(ancestor::scBlock)"/><xsl:variable name="vMaxHx"><xsl:call-template name="maxHeadingNumber"/></xsl:variable>
<xsl:element name="{concat('h', if($vCount &gt; $vMaxHx, $vMaxHx, $vCount))}">
<xsl:apply-templates select="@*"/>
<xsl:apply-overlays/>
<xsl:apply-templates/>
</xsl:element>
</xsl:template>
<xsl:template match="addAttribute">
<xsl:variable name="vAttCo"><xsl:choose><xsl:when test="@filter='textOnly'"><xsl:value-of select="normalize-space(.)"/></xsl:when><xsl:otherwise><redirect:serialize omit-xml-declaration="yes"><xsl:value-of select="."/></redirect:serialize></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:choose>
<xsl:when test="@name = 'lookForAlt'">
<xsl:attribute name="alt"><xsl:value-of select="if(string($vAttCo)='', ancestor::alternative/@alt, $vAttCo)" disable-output-escaping="yes"/></xsl:attribute>
</xsl:when>
<xsl:otherwise>
<xsl:attribute name="{@name}"><xsl:value-of select="$vAttCo" disable-output-escaping="yes"/></xsl:attribute>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template match="@noLocalOutline"/>
<xsl:template match="@tagName"/>
<xsl:template match="@sc-role"/>
	
	<xsl:template match="* | processing-instruction() | comment()"><xsl:copy><xsl:apply-templates select="@*"/><xsl:apply-overlays/><xsl:apply-templates/></xsl:copy></xsl:template>
	<xsl:template match="@* | text()"><xsl:copy/></xsl:template>
</xsl:stylesheet>
